summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/kpilotlink.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/kpilotlink.h')
-rw-r--r--kpilot/lib/kpilotlink.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/kpilot/lib/kpilotlink.h b/kpilot/lib/kpilotlink.h
index 5c3865c3e..b0c97de0f 100644
--- a/kpilot/lib/kpilotlink.h
+++ b/kpilot/lib/kpilotlink.h
@@ -31,8 +31,8 @@
#include <pi-dlp.h>
-#include <qobject.h>
-#include <qvaluelist.h>
+#include <tqobject.h>
+#include <tqvaluelist.h>
/** @file
* Encapsulates all the communication with the handheld. Also
@@ -96,7 +96,7 @@ class PilotDatabase;
* The life-cycle of a KPilotLink object is as follows:
*
* # Object is created (one of the concrete subclasses, anyway)
* # Object gets a location assigned through reset(const QString &)
* # Object is connected to the handheld device (somehow, depends on subclass)
* # Object emits signal deviceReady()
*
@@ -104,7 +104,7 @@ class PilotDatabase;
* the handheld. When the device connection is no longer needed, call either
* endOfSync() or finishSync() to wrap up the communications. The object remains
* alive and may be re-used by calling reset() to use the same location or
* reset(const QString &) to give it a new location.
*
* @section Tickle handling.
*
@@ -174,10 +174,10 @@ Q_OBJECT
friend class SyncAction;
public:
/** A list of DBInfo structures. */
- typedef QValueList<struct DBInfo> DBInfoList;
+ typedef TQValueList<struct DBInfo> DBInfoList;
/** Constructor. Use reset() to start looking for a device. */
- KPilotLink( QObject *parent = 0, const char *name = 0 );
+ KPilotLink( TQObject *parent = 0, const char *name = 0 );
/** Destructor. This rudely interrupts any communication in progress.
* It is best to call endOfSync() or finishSync() before destroying
@@ -187,7 +187,7 @@ public:
/** Provides a human-readable status string. */
- virtual QString statusString() const = 0;
+ virtual TQString statusString() const = 0;
/**
* True if HotSync has been started but not finished yet
@@ -204,7 +204,7 @@ public:
* Whichever is being used, this function returns its
* name in a human-readable form.
*/
- QString pilotPath() const
+ TQString pilotPath() const
{
return fPilotPath;
}
@@ -217,13 +217,13 @@ public:
* @see reset()
* @see pilotPath()
*/
- virtual void reset(const QString &pilotPath) = 0;
+ virtual void reset(const TQString &pilotPath) = 0;
/** Allows our class to receive custom events that our threads
* will be giving to us, including tickle timeouts and
* device communication events.
*/
- virtual bool event(QEvent *e);
+ virtual bool event(TQEvent *e);
/**
* Install the list of files (full paths!) named by @p l
@@ -232,7 +232,7 @@ public:
*
* @return the number of files successfully installed.
*/
- unsigned int installFiles(const QStringList &l, const bool deleteFiles);
+ unsigned int installFiles(const TQStringList &l, const bool deleteFiles);
/**
* Write a log entry to the handheld. If @p log is true,
@@ -241,7 +241,7 @@ public:
* log (with a physical device, that is what appears on
* screen at the end of a sync).
*/
- void addSyncLogEntry(const QString &entry,bool log=true);
+ void addSyncLogEntry(const TQString &entry,bool log=true);
/**
* Find a database with the given @p name (and optionally,
@@ -266,7 +266,7 @@ public:
*
* @return @c true on success
*/
- virtual bool retrieveDatabase(const QString &path, struct DBInfo *db) = 0;
+ virtual bool retrieveDatabase(const TQString &path, struct DBInfo *db) = 0;
/**
* Fill the DBInfo structure @p db with information about
@@ -300,12 +300,12 @@ public:
* @note ownership of the database object is given to the caller,
* who must delete the object in time.
*/
- virtual PilotDatabase *database( const QString &name ) = 0;
+ virtual PilotDatabase *database( const TQString &name ) = 0;
/**
* Return a database object for manipulating the database with
* the name stored in the DBInfo structure @p info . The default
* version goes through method database( const QString & ), above.
*
* @return pointer to database object, or 0 on error.
* @note ownership of the database object is given to the caller.
@@ -387,17 +387,17 @@ signals:
void timeout();
/** Signal that a message has been written to the sync log. */
- void logMessage(const QString &);
+ void logMessage(const TQString &);
/** Signal that an error has occurred, for logging. */
- void logError(const QString &);
+ void logError(const TQString &);
/**
* Signal that progress has been made, for logging purposes.
* @p p is the percentage completed (0 <= s <= 100).
* The string @p s is logged as well, if non-Null.
*/
- void logProgress(const QString &s, int p);
+ void logProgress(const TQString &s, int p);
/**
* Emitted once the user information has been read and
@@ -429,7 +429,7 @@ protected:
* Usually /dev/pilot, /dev/ttySx, or /dev/usb/x. May be
* a filesystem path for local links.
*/
- QString fPilotPath;
+ TQString fPilotPath;
/**
* Start tickling the Handheld (every few seconds). This
@@ -453,7 +453,7 @@ protected:
* @p f is used; in addition, if @p deleteFile is true remove
* the source file. Returns @c true if the install succeeded.
*/
- virtual bool installFile( const QString &f, const bool deleteFile ) = 0;
+ virtual bool installFile( const TQString &f, const bool deleteFile ) = 0;
/**
* Notify the Pilot user that a conduit is running now.
@@ -477,7 +477,7 @@ protected:
* Actually write an entry to the device link. The message
* @p s must be guaranteed non-empty.
*/
- virtual void addSyncLogEntryImpl( const QString &s ) = 0;
+ virtual void addSyncLogEntryImpl( const TQString &s ) = 0;
/**
* User information structure. Should be filled in when a sync
@@ -494,7 +494,7 @@ protected:
private:
bool fTickleDone;
- QThread *fTickleThread;
+ TQThread *fTickleThread;
} ;
@@ -96,7 +96,7 @@ class PilotDatabase;
*
* # Object is created (one of the concrete subclasses, anyway)
-* # Object gets a location assigned through reset(const QString &)
+* # Object gets a location assigned through reset(const TQString &)
* # Object is connected to the handheld device (somehow, depends on subclass)
* # Object emits signal deviceReady()
@@ -104,7 +104,7 @@ class PilotDatabase;
* endOfSync() or finishSync() to wrap up the communications. The object remains
* alive and may be re-used by calling reset() to use the same location or
-* reset(const QString &) to give it a new location.
+* reset(const TQString &) to give it a new location.
*
* @section Tickle handling.
@@ -300,12 +300,12 @@ public:
* Return a database object for manipulating the database with
* the name stored in the DBInfo structure @p info . The default
- * version goes through method database( const QString & ), above.
+ * version goes through method database( const TQString & ), above.
*
* @return pointer to database object, or 0 on error.